@@ -35,7 +35,7 @@ def csvCleaner(csv_folder, csv_folder_cleaned):
 
 # CSV Encoding
 def csv_encoding(csvFile, csv_folder_encoding):
-    data = pd.read_csv(csvFile, encoding='utf-8')
+    data = pd.read_csv(csvFile, encoding='utf-8', low_memory=False)
     data.to_csv(csv_folder_encoding + "\\ENCOD_" + os.path.basename(csvFile), encoding='utf-8-sig', index = False)
 
 def csvEncoder(csv_folder, csv_folder_encoding):
@@ -117,7 +117,7 @@ def unicodeProcess(dataframe):
     dataframe['title'] = dataframe['title'].str.replace(' ', ' ')
 
 
-def csvImporter_NEW(csv_folder_cleaned, keyword_pool, skima, column_name):
+def csvImporter_NEW(csv_folder_cleaned, keyword_pool, schema, column_name):
     # column_name = ["retailer_id", "retailer_name", "retailer_sku", "upc", "model_number", "title", "brand", "category", "subcategory", "week_id", "week_ending", "units_sold", "retail_sales", "retail_price", "conversion_rate", "total_traffic", "organic_traffic"]
 
     fileList = os.listdir(csv_folder_cleaned)
@@ -136,29 +136,29 @@ def csvImporter_NEW(csv_folder_cleaned, keyword_pool, skima, column_name):
             db_table_name = 'tb_stackline_laptops'
             # commonPreprocess(dataframe)
             print("-----No Pool Check-----")
-            stackTodb(dataframe, db_table_name, skima)
+            stackTodb(dataframe, db_table_name, schema)
 
         if "Earbud" in fileList[i]:
             db_table_name = 'tb_stackline_earbuds'
             # commonPreprocess(dataframe)
             print("-----No Pool Check-----")
-            stackTodb(dataframe, db_table_name, skima)
+            stackTodb(dataframe, db_table_name, schema)
 
         ##### pool
         if "Watches" in fileList[i]:
             db_table_name = 'tb_stackline_watches'
             print("-----Pool Check-----")
-            stackTodb(addPoolColumn(dataframe, keyword_pool), db_table_name, skima)
+            stackTodb(addPoolColumn(dataframe, keyword_pool), db_table_name, schema)
 
         if "Tablets" in fileList[i]:
             db_table_name = 'tb_stackline_tablets'
             print("-----Pool Check-----")
-            stackTodb(addPoolColumn(dataframe, keyword_pool), db_table_name, skima)
+            stackTodb(addPoolColumn(dataframe, keyword_pool), db_table_name, schema)
 
         if "Phones" in fileList[i]:
             db_table_name = 'tb_stackline_smartphones'
             print("-----Pool Check-----")
-            stackTodb(addPoolColumn(dataframe, keyword_pool), db_table_name, skima)
+            stackTodb(addPoolColumn(dataframe, keyword_pool), db_table_name, schema)
 
 
 def keywordCheck(csv_folder_cleaned, pool_check_folder, keyword_pool, column_name):
